@@ -7,12 +7,10 @@
 #include <FL/Fl_Color_Chooser.H>
 
 class LED : public Fl_Group {
-    
-public:
-
+  public:
     enum LED_STATE {
         LED_OFF = 0,
-        LED_ON = 1
+        LED_ON = 1,
     };
 
     int width, height;
@@ -21,13 +19,12 @@ public:
 
     Fl_Color LED_color;
     Fl_Color bg_color;
-    
-    LED(int X, int Y, int W, int H, const char*L=0);
+
+    LED(int X, int Y, int W, int H, const char *L = 0);
 
     void set_color(Fl_Color color);
     void set_state(LED_STATE state);
     void draw();
 };
 
-
 #endif // FL_VU_METER_H
