@@ -16,19 +16,31 @@
 #ifndef FL_CALLBACKS_H
 #define FL_CALLBACKS_H
 
-enum { STREAM_TIME = 0, REC_TIME, SENT_DATA, REC_DATA };
-enum { STREAM = 0, RECORD };
+enum {
+    STREAM_TIME = 0,
+    REC_TIME,
+    SENT_DATA,
+    REC_DATA,
+};
+enum {
+    STREAM = 0,
+    RECORD,
+};
 
 class flgui;
 
 extern int display_info;
 extern flgui *fl_g;
 
+void show_vu_tabs(void);
+void hide_vu_tabs(void);
+
 void button_cfg_cb(void);
+void button_mixer_cb(void);
 void button_info_cb(void);
-void button_record_cb(void);
+void button_record_cb(bool ask);
 void button_connect_cb(void);
-void button_disconnect_cb(void);
+void button_disconnect_cb(bool ask);
 void button_add_icy_add_cb(void);
 void button_cfg_del_srv_cb(void);
 void button_cfg_del_icy_cb(void);
@@ -46,7 +58,6 @@ void choice_cfg_codec_aac_cb(void);
 void choice_cfg_codec_flac_cb(void);
 void button_cfg_export_cb(void);
 void button_cfg_import_cb(void);
-void check_cfg_mono_to_stereo_cb(void);
 void button_add_icy_save_cb(void);
 void button_add_srv_cancel_cb(void);
 void button_add_icy_cancel_cb(void);
@@ -66,11 +77,14 @@ void input_cfg_absent_level_cb(void);
 void choice_cfg_resample_mode_cb(void);
 void button_cfg_check_for_updates_cb(void);
 void choice_cfg_dev_cb(void);
+void choice_cfg_dev2_cb(void);
 void button_cfg_rescan_devices_cb(void);
 void radio_cfg_ID_cb(void);
 void radio_cfg_name_cb(void);
 void choice_cfg_right_channel_cb(void);
 void choice_cfg_left_channel_cb(void);
+void choice_cfg_right_channel2_cb(void);
+void choice_cfg_left_channel2_cb(void);
 
 void button_add_srv_add_cb(void);
 void button_add_srv_save_cb(void);
@@ -89,6 +103,8 @@ void check_update_at_startup_cb(void);
 void check_start_agent_cb(void);
 void check_minimize_to_tray_cb(void);
 
+void button_stream_codec_settings_cb(void);
+
 void button_rec_browse_cb(void);
 void button_rec_split_now_cb(void);
 void choice_rec_bitrate_cb(void);
@@ -101,6 +117,7 @@ void choice_rec_codec_wav_cb(void);
 void choice_rec_codec_opus_cb(void);
 void choice_rec_codec_aac_cb(void);
 void choice_rec_codec_flac_cb(void);
+void button_rec_codec_settings_cb(void);
 void input_rec_signal_cb(void);
 void input_rec_silence_cb(void);
 
@@ -127,16 +144,21 @@ void check_gui_hide_log_window_cb(void);
 void check_gui_remember_pos_cb(void);
 void check_gui_lcd_auto_cb(void);
 void check_gui_start_minimized_cb(void);
+void check_gui_disable_gain_slider_cb(void);
+void check_gui_show_listeners_cb(void);
 void button_gui_bg_color_cb(void);
 void button_gui_text_color_cb(void);
 void choice_gui_language_cb(void);
 void radio_gui_vu_gradient_cb(void);
 void radio_gui_vu_solid_cb(void);
-
+void check_gui_always_show_vu_tabs_cb(void);
 
 void slider_gain_cb(void);
+void vu_tabs_cb(void);
 
 void check_activate_eq_cb(void);
+void button_eq_reset_cb(void);
+void choice_eq_preset_cb(void);
 void slider_equalizer1_cb(double);
 void slider_equalizer2_cb(double);
 void slider_equalizer3_cb(double);
@@ -149,6 +171,7 @@ void slider_equalizer9_cb(double);
 void slider_equalizer10_cb(double);
 
 void check_activate_drc_cb(void);
+void button_drc_reset_cb(void);
 void check_aggressive_mode_cb(void);
 void slider_threshold_cb(double);
 void slider_ratio_cb(double);
@@ -156,6 +179,16 @@ void slider_attack_cb(double);
 void slider_release_cb(double);
 void slider_makeup_cb(double);
 
+void slider_mixer_primary_device_cb(double);
+void slider_mixer_secondary_device_cb(double);
+void slider_mixer_streaming_gain_cb(double);
+void slider_mixer_recording_gain_cb(double);
+void slider_mixer_master_gain_cb(double);
+void slider_mixer_cross_fader_cb(double);
+void button_mixer_reset_cb(void);
+void button_mixer_mute_primary_device_cb(void);
+void button_mixer_mute_secondary_device_cb(void);
+
 void check_cfg_auto_start_rec_cb(void);
 void check_cfg_auto_stop_rec_cb(void);
 void check_cfg_rec_after_launch_cb(void);
@@ -164,9 +197,9 @@ void check_cfg_rec_hourly_cb(void);
 void check_cfg_connect_cb(void);
 void check_cfg_force_reconnecting_cb(void);
 
-void lcd_rotate(void*);
+void lcd_rotate(void *);
 void ILM216_cb(void);
-void window_main_close_cb(void);
+void window_main_close_cb(bool ask);
 
 void check_cfg_use_app_cb(void);
 void choice_cfg_app_cb(void);
@@ -175,8 +208,7 @@ void radio_cfg_title_artist_cb(void);
 
 void choice_cfg_song_delay_cb(void);
 
-
-void update_song(void* user_data);
+void update_song(void *user_data);
 bool stop_recording(bool ask);
 
 void choice_stream_mp3_enc_quality_cb(void);
@@ -200,6 +232,8 @@ void choice_stream_aac_profile_cb(void);
 void choice_stream_aac_afterburner_cb(void);
 void choice_stream_aac_bitrate_mode_cb(void);
 
+void radio_stream_flac_bit_depth_16_cb(void);
+void radio_stream_flac_bit_depth_24_cb(void);
 
 void choice_rec_mp3_enc_quality_cb(void);
 void choice_rec_mp3_stereo_mode_cb(void);
@@ -222,7 +256,11 @@ void choice_rec_aac_profile_cb(void);
 void choice_rec_aac_afterburner_cb(void);
 void choice_rec_aac_bitrate_mode_cb(void);
 
+void radio_rec_flac_bit_depth_16_cb(void);
+void radio_rec_flac_bit_depth_24_cb(void);
 
+void radio_rec_wav_bit_depth_16_cb(void);
+void radio_rec_wav_bit_depth_24_cb(void);
+void radio_rec_wav_bit_depth_32_cb(void);
 
 #endif
-
