@@ -16,29 +16,30 @@
 #ifndef FL_TIMER_FUNCS_H
 #define FL_TIMER_FUNCS_H
 
-void display_info_timer(void*);
-void agent_watchdog_timer(void*);
-void has_agent_been_started_timer(void*);
-void has_agent_been_stopped_timer(void*);
-void vu_meter_timer(void*);
-void cmd_timer(void*);
-void is_connected_timer(void*);
-void cfg_win_pos_timer(void*);
-void songfile_timer(void*);
-void stream_silence_timer(void*);
-void record_silence_timer(void*);
-void stream_signal_timer(void*);
-void record_signal_timer(void*);
-void wait_for_radioco_timer(void*);
+void display_info_timer(void *);
+void agent_watchdog_timer(void *);
+void has_agent_been_started_timer(void *);
+void has_agent_been_stopped_timer(void *);
+void vu_meter_timer(void *);
+void cmd_timer(void *);
+void is_connected_timer(void *);
+void cfg_win_pos_timer(void *);
+void songfile_timer(void *);
+void stream_silence_timer(void *);
+void record_silence_timer(void *);
+void stream_signal_timer(void *);
+void record_signal_timer(void *);
+void wait_for_radioco_timer(void *);
+void request_listener_count_timer(void *reset);
 
-void display_rotate_timer(void*);
-void app_timer(void*);
+void display_rotate_timer(void *);
+void app_timer(void *);
 
 void split_recording_file_timer(void);
 void split_recording_file(void);
 
-extern const char* (*current_track_app)(int);
-
+extern const char *(*current_track_app)(int);
+extern int g_vu_meter_timer_is_active;
+extern int g_stop_vu_meter_timer;
 
 #endif
-
