@@ -21,9 +21,9 @@
 #ifdef HAVE_LIBFDK_AAC
 
 #if defined(WIN32) || defined(__APPLE__)
- #include "aac_dll.h"
+#include "aac_dll.h"
 #else
- #include <fdk-aac/aacenc_lib.h>
+#include <fdk-aac/aacenc_lib.h>
 #endif
 
 struct aac_enc {
@@ -40,11 +40,12 @@ struct aac_enc {
 
 enum {
     AAC_READY = 0,
-    AAC_BUSY = 1
+    AAC_BUSY = 1,
 };
 
 int aac_enc_init(aac_enc *aac);
-int aac_enc_encode(aac_enc *aac, short *pcm_buf, char *enc_buf, int samples, int size);
+int aac_enc_encode(aac_enc *aac, float *pcm_buf, char *enc_buf, int samples, int size);
+int aac_enc_get_samplerate(aac_enc *aac);
 int aac_enc_reinit(aac_enc *aac);
 void aac_enc_close(aac_enc *aac);
 
@@ -53,4 +54,3 @@ void aac_enc_close(aac_enc *aac);
 extern int g_aac_lib_available;
 
 #endif // AAC_ENCODE_H
-
