@@ -8,8 +8,10 @@
 
 #include "currentTrack.h"
 
-currentTrackFunction getCurrentTrackFunctionFromId(int i) {
-    switch(i) {
-        default: return NULL;
+currentTrackFunction getCurrentTrackFunctionFromId(int i)
+{
+    switch (i) {
+    default:
+        return NULL;
     }
 }
\ No newline at end of file
