@@ -23,10 +23,17 @@ enum {
     IC_ASK = 3,
 };
 
+enum {
+    IC_TYPE_UNKNOWN = -1,
+    IC_TYPE_KH = 0,
+    IC_TYPE_VANILLA = 1,
+};
+
 int ic_init(void);
 int ic_connect(void);
 int ic_send(char *buf, int buf_len);
 int ic_update_song(char *song_name);
+int ic_get_listener_count(void);
 void ic_disconnect(void);
 
 #endif
