@@ -39,28 +39,24 @@ int lame_enc_init(lame_enc *lame)
     lame_set_VBR_mean_bitrate_kbps(lame->gfp, lame->bitrate);
     lame_set_VBR_max_bitrate_kbps(lame->gfp, lame->vbr_max_bitrate);
 
-    if (lame->stereo_mode > -1)
+    if (lame->stereo_mode > -1) {
         lame_set_mode(lame->gfp, (MPEG_mode)lame->stereo_mode);
+    }
 
-    if (lame->bitrate_mode == 0) // CBR
+    if (lame->bitrate_mode == 0) { // CBR
         lame_set_VBR(lame->gfp, vbr_off);
+    }
 
-    if (lame->bitrate_mode == 1) // VBR
-    {
+    if (lame->bitrate_mode == 1) { // VBR
         lame_set_VBR(lame->gfp, vbr_default);
     }
 
-    if (lame->bitrate_mode == 2) // ABR
-    {
+    if (lame->bitrate_mode == 2) { // ABR
         lame_set_VBR(lame->gfp, vbr_abr);
     }
 
-
-    
-    if((rc = lame_init_params(lame->gfp)) < 0)
-    {
-        snprintf(info_buf, sizeof(info_buf),
-                _("unable to init lame params %d"), rc);
+    if ((rc = lame_init_params(lame->gfp)) < 0) {
+        snprintf(info_buf, sizeof(info_buf), _("unable to init lame params %d"), rc);
 
         print_info(info_buf, 1);
         return 1;
@@ -83,43 +79,48 @@ int lame_enc_init(lame_enc *lame)
 
 int lame_enc_reinit(lame_enc *lame)
 {
-    if(lame != NULL)
-    {
+    if (lame != NULL) {
         lame_enc_close(lame);
         return lame_enc_init(lame);
     }
     return 1;
 }
 
+int lame_enc_get_samplerate(lame_enc *lame)
+{
+    return lame_get_out_samplerate(lame->gfp);
+}
+
 void lame_enc_close(lame_enc *lame)
 {
-    while(lame->state == LAME_BUSY)
-       ;
+    while (lame->state == LAME_BUSY)
+        ;
 
-    if (lame->gfp != NULL)
+    if (lame->gfp != NULL) {
         lame_close(lame->gfp);
-    
+    }
+
     lame->gfp = NULL;
 }
 
-int lame_enc_encode(lame_enc *lame, short *pcm_buf, char *enc_buf, int samples, int size)
+int lame_enc_encode(lame_enc *lame, float *pcm_buf, char *enc_buf, int samples, int size)
 {
     int rc;
 
-    if(samples == 0 || lame->gfp == NULL)
+    if (samples == 0 || lame->gfp == NULL) {
         return 0;
+    }
 
     lame->state = LAME_BUSY;
 
-
-    if(lame->channel == 2) // stereo
-        rc = lame_encode_buffer_interleaved(lame->gfp, pcm_buf, samples, (unsigned char*)enc_buf, size);
-    else // mono
-        rc = lame_encode_buffer(lame->gfp, pcm_buf, pcm_buf, samples, (unsigned char*)enc_buf, size);
-
+    if (lame->channel == 2) { // stereo
+        rc = lame_encode_buffer_interleaved_ieee_float(lame->gfp, pcm_buf, samples, (unsigned char *)enc_buf, size);
+    }
+    else { // mono
+        rc = lame_encode_buffer_ieee_float(lame->gfp, pcm_buf, pcm_buf, samples, (unsigned char *)enc_buf, size);
+    }
 
     lame->state = LAME_READY;
 
     return rc;
 }
-
