@@ -19,7 +19,6 @@
 #include <stdlib.h>
 #include <lame/lame.h>
 
-
 struct lame_enc {
     lame_global_flags *gfp;
     int bitrate;
@@ -37,13 +36,13 @@ struct lame_enc {
 
 enum {
     LAME_READY = 0,
-    LAME_BUSY = 1
+    LAME_BUSY = 1,
 };
 
 int lame_enc_init(lame_enc *lame);
-int lame_enc_encode(lame_enc *lame, short *pcm_buf, char *enc_buf, int samples, int size);
+int lame_enc_get_samplerate(lame_enc *lame);
+int lame_enc_encode(lame_enc *lame, float *pcm_buf, char *enc_buf, int samples, int size);
 int lame_enc_reinit(lame_enc *lame);
 void lame_enc_close(lame_enc *lame);
 
 #endif
-
