@@ -13,7 +13,7 @@
 // GNU General Public License for more details.
 //
 
-#ifndef SHOUTCAST_H 
+#ifndef SHOUTCAST_H
 #define SHOUTCAST_H
 
 enum {
@@ -23,10 +23,16 @@ enum {
     SC_ASK = 3,
 };
 
+enum {
+    SC_VERSION_UNKNOWN = 0,
+    SC_VERSION_1 = 1,
+    SC_VERSION_2 = 2,
+};
+
 int sc_update_song(char *song_name);
 int sc_connect(void);
 int sc_send(char *buf, int buf_len);
 void sc_disconnect(void);
+int sc_get_listener_count(void);
 
 #endif
-
