@@ -18,49 +18,73 @@
 
 #include "timer.h"
 
-
-void timer_init(sec_timer *t, int duration)
+void timer_init(timer_ms_t *t, float duration)
 {
-    t->start_time = time(NULL);
-    t->new_time = t->start_time;
     t->duration = duration;
+    t->is_running = false;
+}
+
+void timer_start(timer_ms_t *t)
+{
+    t->start_time = timer_get_cur_time();
+    t->new_time = t->start_time;
     t->is_running = true;
 }
 
-int timer_is_elapsed(sec_timer *t)
+int timer_is_elapsed(timer_ms_t *t)
 {
+    uint64_t cur_time = timer_get_cur_time();
+    uint64_t duration = t->duration * 1000;
 
-    if(time(NULL) >= t->new_time + t->duration)
-    {
-        t->new_time = time(NULL); //reset the timer
+    if (cur_time >= t->new_time + duration) {
+        t->new_time = timer_get_cur_time();
         return 1;
     }
-    else
+    else {
         return 0;
+    }
 }
 
-char *timer_get_time_str(sec_timer *t)
+char *timer_get_time_str(timer_ms_t *t)
 {
     static char time_str[64];
-    int hour = 0, min = 0, sec = 0;
-    time_t cur_time = time(NULL);
+    long hour = 0, min = 0, sec = 0;
+    uint64_t cur_time = timer_get_cur_time();
 
-    sec = cur_time - t->start_time;
+    sec = (cur_time - t->start_time) / 1000;
 
     min = sec / 60;
     hour = min / 60;
     min %= 60;
     sec %= 60;
 
-    snprintf(time_str, sizeof(time_str), "%02d:%02d:%02d", hour, min, sec);
+    snprintf(time_str, sizeof(time_str), "%02ld:%02ld:%02ld", hour, min, sec);
 
     return time_str;
 }
 
-void timer_reset(sec_timer *t)
+float timer_get_elapsed_time(timer_ms_t *t)
+{
+    uint64_t diff_time = timer_get_cur_time() - t->start_time;
+    return float(diff_time / 1000.0);
+}
+
+void timer_reset(timer_ms_t *t)
 {
     t->is_running = false;
-    t->start_time = time(NULL);
+    t->start_time = timer_get_cur_time();
     t->new_time = t->start_time;
 }
 
+void timer_stop(timer_ms_t *t)
+{
+    t->is_running = false;
+}
+
+uint64_t timer_get_cur_time(void)
+{
+    struct timeval time;
+    gettimeofday(&time, NULL);
+
+    return (uint64_t)time.tv_sec * 1000 + time.tv_usec / 1000;
+}
