@@ -23,7 +23,7 @@ enum tray_agent_cmd {
     TA_MINIMIZE = 1,
     TA_SERVER_NAME = 2,
     TA_CONNECT_STATE = 3,
-    TA_SONG_UPDATE = 4
+    TA_SONG_UPDATE = 4,
 };
 
 int tray_agent_start(void);
@@ -32,6 +32,5 @@ int tray_agent_send_cmd(int cmd);
 int tray_agent_is_running(HWND *hwAgent);
 void tray_agent_set_song(char *song);
 
-
 #endif // ifdef WIN32
 #endif // ifndef TRAY_AGENT_H
