@@ -18,21 +18,20 @@
 
 #include <vorbis/vorbisenc.h>
 
-
 struct vorbis_enc {
     ogg_stream_state os; /* take physical pages, weld into a logical stream of packets */
-    ogg_page         og; /* one Ogg bitstream page.  Vorbis packets are inside */
-    ogg_packet       op; /* one raw packet of data for decode */
-    vorbis_info      vi;
-    vorbis_comment   vc; /* struct that stores all the user comments */
-    vorbis_block     vb;
+    ogg_page og;         /* one Ogg bitstream page.  Vorbis packets are inside */
+    ogg_packet op;       /* one raw packet of data for decode */
+    vorbis_info vi;
+    vorbis_comment vc; /* struct that stores all the user comments */
+    vorbis_block vb;
     vorbis_dsp_state vd; /* central working state for the packet->PCM decoder */
 
     int bitrate;
     int samplerate;
     int channel;
     int state;
-    
+
     int bitrate_mode;
     float vbr_quality;
     int vbr_min_bitrate;
@@ -41,14 +40,14 @@ struct vorbis_enc {
 
 enum {
     VORBIS_READY = 0,
-    VORBIS_BUSY = 1
+    VORBIS_BUSY = 1,
 };
 
-extern vorbis_info  vorbis_vi;
-extern char* vorbis_buf;
+extern vorbis_info vorbis_vi;
+extern char *vorbis_buf;
 
 int vorbis_enc_init(vorbis_enc *vorbis);
-int vorbis_enc_encode(vorbis_enc *vorbis, short *pcm_buf, char *enc_buf, int size);
+int vorbis_enc_encode(vorbis_enc *vorbis, float *pcm_buf, char *enc_buf, int size);
 
 int vorbis_enc_reinit(vorbis_enc *vorbis);
 
@@ -56,6 +55,6 @@ void vorbis_enc_write_header(vorbis_enc *vorbis);
 void vorbis_enc_close(vorbis_enc *vorbis);
 
 void vorbis_enc_new_song(vorbis_enc *vorbis, char *song);
+int vorbis_enc_get_samplerate(vorbis_enc *vorbis);
 
 #endif
-
